--- CMakeLists.txt.orig
+++ CMakeLists.txt
@@ -105,6 +105,7 @@
 ########################################################################
 find_package(CppUnit)
 find_package(Doxygen)
+find_package(Volk)
 
 # Search for GNU Radio and its components and versions. Add any
 # components required to the list of GR_REQUIRED_COMPONENTS (in all
@@ -117,6 +118,30 @@
     message(FATAL_ERROR "CppUnit required to compile gr-ais")
 endif()
 
+if(NOT VOLK_FOUND)
+    message(FATAL_ERROR "Volk required to compile gr-ais")
+endif()
+
+########################################################################
+# On Apple only, set install name and use rpath correctly, if not already set
+########################################################################
+if(APPLE)
+   if(NOT CMAKE_INSTALL_NAME_DIR)
+       set(CMAKE_INSTALL_NAME_DIR
+           ${CMAKE_INSTALL_PREFIX}/${GR_LIBRARY_DIR} CACHE
+           PATH "Library Install Name Destination Directory" FORCE)
+   endif(NOT CMAKE_INSTALL_NAME_DIR)
+   if(NOT CMAKE_INSTALL_RPATH)
+       set(CMAKE_INSTALL_RPATH
+           ${CMAKE_INSTALL_PREFIX}/${GR_LIBRARY_DIR} CACHE
+           PATH "Library Install RPath" FORCE)
+   endif(NOT CMAKE_INSTALL_RPATH)
+   if(NOT CMAKE_BUILD_WITH_INSTALL_RPATH)
+       set(CMAKE_BUILD_WITH_INSTALL_RPATH ON CACHE
+           BOOL "Do Build Using Library Install RPath" FORCE)
+   endif(NOT CMAKE_BUILD_WITH_INSTALL_RPATH)
+endif(APPLE)
+
 ########################################################################
 # Setup doxygen option
 ########################################################################
@@ -137,12 +162,14 @@
     ${Boost_INCLUDE_DIRS}
     ${CPPUNIT_INCLUDE_DIRS}
     ${GNURADIO_ALL_INCLUDE_DIRS}
+    ${VOLK_INCLUDE_DIRS}
 )
 
 link_directories(
     ${Boost_LIBRARY_DIRS}
     ${CPPUNIT_LIBRARY_DIRS}
     ${GNURADIO_RUNTIME_LIBRARY_DIRS}
+    ${VOLK_LIBRARY_DIRS}
 )
 
 # Set component parameters
@@ -175,6 +202,10 @@
 ########################################################################
 # Install cmake search helper for this library
 ########################################################################
+if(NOT CMAKE_MODULES_DIR)
+    set(CMAKE_MODULES_DIR lib${LIB_SUFFIX}/cmake)
+endif(NOT CMAKE_MODULES_DIR)
+
 install(FILES cmake/Modules/aisConfig.cmake
-    DESTINATION lib/cmake/ais
+    DESTINATION ${CMAKE_MODULES_DIR}/ais
 )
--- lib/CMakeLists.txt.orig
+++ lib/CMakeLists.txt
@@ -22,8 +22,6 @@
 ########################################################################
 include(GrPlatform) #define LIB_SUFFIX
 
-include_directories(${Boost_INCLUDE_DIR})
-link_directories(${Boost_LIBRARY_DIRS})
 list(APPEND ais_sources
     freqest_impl.cc
     invert_impl.cc
@@ -40,15 +38,10 @@
 endif(NOT ais_sources)
 
 add_library(gnuradio-ais SHARED ${ais_sources})
-target_link_libraries(gnuradio-ais ${Boost_LIBRARIES} ${GNURADIO_ALL_LIBRARIES})
+target_link_libraries(gnuradio-ais ${Boost_LIBRARIES}
+    ${GNURADIO_ALL_LIBRARIES} ${VOLK_LIBRARIES})
 set_target_properties(gnuradio-ais PROPERTIES DEFINE_SYMBOL "gnuradio_ais_EXPORTS")
 
-if(APPLE)
-    set_target_properties(gnuradio-ais PROPERTIES
-        INSTALL_NAME_DIR "${CMAKE_INSTALL_PREFIX}/lib"
-    )
-endif(APPLE)
-
 ########################################################################
 # Install built library files
 ########################################################################
